@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1.1-rc1"
-#define PACKAGE_STRING "am-utils 6.1.1-rc1"
+#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_STRING "am-utils 6.2a1"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i686"
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.6.5-7.151-smp"
+#define HOST_OS_VERSION "2.6.8-24.16-default"
 #define HOST_ARCH "i386"
-#define DISTRO_NAME "suse9.1"
-#define HOST_NAME "dhcp2"
+#define DISTRO_NAME "suse9.2"
+#define HOST_NAME "a-suse92"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Jun 25 14:28:31 EDT 2005"
+#define CONFIG_DATE "Wed Jul 20 08:56:33 PDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1.1-rc1"
+#define PACKAGE_VERSION "6.2a1"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1.1-rc1"
+#define VERSION "6.2a1"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -32,10 +32,9 @@
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
 #ifdef __cplusplus
-void exit (int);
+#include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "2.6.4"
-#define YYTEXT_POINTER 1
+#define HOST_HEADER_VERSION "2.6.8.1"
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
 #define HAVE_LIBRT 1
@@ -86,8 +85,8 @@ void exit (int);
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
-#define HAVE_STRCHR 1
 #define HAVE_STRCASECMP 1
+#define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
@@ -275,7 +274,6 @@ void exit (int);
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
-#define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
 #define HAVE_NFS_ARGS_T_BSIZE 1
@@ -285,6 +283,7 @@ void exit (int);
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_NISPLUS 1
@@ -337,6 +336,8 @@ void exit (int);
 #define MNTTAB_OPT_RW "rw"
 #define MNTTAB_OPT_SUID "suid"
 #define MNT2_GEN_OPT_BIND 0x1000
+#define MNT2_GEN_OPT_DETACH 0x2
+#define MNT2_GEN_OPT_FORCE 0x1
 #define MNT2_GEN_OPT_NODEV 0x4
 #define MNT2_GEN_OPT_NOEXEC 0x8
 #define MNT2_GEN_OPT_NOSUID 0x2
